clear all
close all
clc

parameters

%% Calculate Flow 3
p.Q3.l = p.Q1.l+p.Q2.l; % Liquid volumetric flow [m3/s]
p.Q3.g = p.Q1.g+p.Q2.g; % Gas volumetric flow [m3/s]
p.w3 = p.w1+p.w2; % Sand production rate [m3/s]

%% Calculation of the erosion in the bends
[ER.bend1 p] = bend(p.Q1.l, p.Q1.g, p.D1, p.w1, p); % Erosion rate bend 1 [mm/year]
[ER.bend2 p] = bend(p.Q2.l, p.Q2.g, p.D1, p.w2, p); % Erosion rate bend 2 [mm/year]
[ER.bend3 p] = bend(p.Q3.l, p.Q3.g, p.D2, p.w3, p); % Erosion rate bend 3 [mm/year]

%% Erosion in choke valve 1 and 2
[ER.choke1 p] = choke(p.Q1.l, p.Q1.g, p.w1, p);
[ER.choke2 p] = choke(p.Q2.l, p.Q2.g, p.w2, p);

%% Initial wall thickness
bend1(1) = 10; % Initial wall thickness [mm]
bend2(1) = 10; % Initial wall thickness [mm]
bend3(1) = 10; % Initial wall thickness [mm]
choke1(1) = 10;
choke2(1) = 10;

n = 30; % Time scope [year]

for i = 2:n+1
    bend1(i) = bend1(i-1)-ER.bend1;
    bend2(i) = bend2(i-1)-ER.bend2;
    bend3(i) = bend3(i-1)-ER.bend3;
    choke1(i) = choke1(i-1)-ER.choke1;
    choke2(i) = choke2(i-1)-ER.choke2;
end

%% The plot
plot(0:n, bend1, 0:n, bend2, 0:n, bend3, 0:n, choke1, 0:n, choke2)
title('Basic case: system erosion', 'FontSize', 14)
xlim([0 n])
ylim([0 10])
xlabel('Time [year]')
ylabel('Wall thickness [mm]')
legend('Elbow 1', 'Elbow 2', 'Elbow 3', 'Choke 1' , 'Choke 2' )

ER