function [ER p] = bend(Q_l, Q_g, D, W, p)
    %% Step 1: Determine stagnation length, L
    L0 = (1-1.27*atan(1.01*D^(-1.89))+D^0.129)*1.18; % Stagnation length [inches]
    p.L = L0*2.54/100; % Stagnation length [inches] to [m]
    D_m = D*2.54/100; % Diameter [inches] to [m]
    
    %% Step 2: Determine flow velocity profile
    A = (pi*D_m^2)/4; % Cross sectional area
    V.sl = Q_l/A; % Superficial liquid velocity
    V.sg = Q_g/A; % Superficial gas velocity
    
    p.rho_m = (V.sl*p.rho.l)/(V.sg+V.sl)+(V.sg*p.rho.g)/(V.sl+V.sg); % Micture density [kg/m3]
    p.mu_m = (V.sl*p.mu.l)/(V.sg+V.sl)+(V.sg*p.mu.g)/(V.sl+V.sg); % Mixture viscosity [kg/ms]
        
    p.V_char = V.sl;
    
    %% Step 3: Determine the particle impact velocity
    [x,V_p] = ode45(@(x, V_p) dvdx(x, V_p, p), [0 1], 1);
    V_p = V_p*p.V_char; % Vector of particle velocities from x = 0 to x = L
    V_L = V_p(end); % Particle impact velocity [m/s]
    
    if V_L < 0
        V_L = 0;
    end
    
    
    
    %% Step 4: Determine the erosion rate
    F_m = (1.95e-5)/(120^-0.59); % Material hardness factor CS [-]
    F_s = 0.53; % Sharpness factor [-]
    F_p = 206/1000; % Penetration factor [m/kg]
    Dref = 1; % [inches]
    r_c = 1.5; % [-]
    F_rD = exp(-(0.1*(p.rho_m^0.4*p.mu_m^0.65)/(p.d_p^0.3)+0.015*p.rho_m^0.25+0.12)*(r_c-1.5)); % Radius curvature factor [-]
        
    ER = F_m*F_s*F_p*F_rD*(W*V_L^1.73)*3600*24*365*1000/(D/Dref)^2; % Erosion rate [mm/year]
end