clear all
close all
clc

parameters

%% Calculate Flow 3
p.Q3.l = p.Q1.l+p.Q2.l; % Liquid volumetric flow [m3/s]
p.Q3.g = p.Q1.g+p.Q2.g; % Gas volumetric flow [m3/s]
p.w3 = p.w1+p.w2; % Sand production rate [m3/s]

%% Initial wall thickness
bend1(1:10,1) = 10; % Initial wall thickness [mm]
bend2(1:10,1) = 10; % Initial wall thickness [mm]
bend3(1:10,1) = 10; % Initial wall thickness [mm]
choke1(1:10,1) = 10; % Initial wall thickness [mm]
choke2(1:10,1) = 10; % Initial wall thickness [mm]

%% Calculate the different erosion rates
t = 1; % counter
x = 0.1:0.1:1; % interval
for n = x % Gas volumetric flow 2
    p.Q3.g = p.Q1.g + n ; % Gas volumetric flow 3
    
    [ER.bend1(t) p] = bend(p.Q1.l, p.Q1.g, p.D1, p.w1, p); % Erosion rate elbow 1 [mm/year]
    [ER.bend2(t) p] = bend(p.Q2.l, n, p.D1, p.w1, p); % Erosion rate elbow 2 [mm/year]    
    [ER.bend3(t) p] = bend(p.Q3.l, p.Q3.g, p.D2, p.w3, p); % Erosion rate elbow 3 [mm/year]
    [ER.choke1(t) p] = choke(p.Q1.l, p.Q1.g, p.w1, p); % Erosion rate choke 1 [mm/year]
    [ER.choke2(t) p] = choke(p.Q2.l, n, p.w2, p); % Erosion rate choke 2 [mm/year]
    
    t = t + 1;
end

j = 1; % Counter
f = 30; % Field lifetime

for i = 1:10
    % Elbow 1    
    if ER.bend1(i) > 0 %% In case no/very little erosion --> never-ending while loop
        while bend1(i,j) > 0
            bend1(i,j+1) = bend1(i,j) - ER.bend1(i); % calculating wall thickness
            j = j + 1; % counting years
        end
        b1(i) = j-1; 
    else
        b1(i) = nan;
    end 
    
    j = 1;
    
    % Elbow 2    
    if ER.bend2(i) > 0 %% In case no/very little erosion --> never-ending while loop
        while bend2(i,j) > 0
            bend2(i,j+1) = bend2(i,j) - ER.bend2(i); % calculating wall thickness
            j = j + 1; % counting years
        end
        b2(i) = j-1; 
    else
        b2(i) = nan;
    end 
    
    
    j = 1;
    
    % Elbow 3   
    if ER.bend3(i) > 0 %% In case no/very little erosion --> never-ending while loop
        while bend3(i,j) > 0
            bend3(i,j+1) = bend3(i,j) - ER.bend3(i); % calculating wall thickness
            j = j + 1; % counting years       
        end
        b3(i) = j-1; 
    else
        b3(i) = nan;
    end 
     
    j = 1;
    
    % Choke 1  
    if ER.choke1(i) > 0 %% In case no/very little erosion --> never-ending while loop
        while choke1(i,j) > 0
            choke1(i,j+1) = choke1(i,j) - ER.choke1(i); % calculating wall thickness
            j = j + 1; % counting years
        end
        c1(i) = j-1; 
    else
        c1(i) = nan;
    end 
     
    j = 1;
    
    % Choke 2  
    if ER.choke2(i) > 0 %% In case no/very little erosion --> never-ending while loop
        while choke2(i,j) > 0
            choke2(i,j+1) = choke2(i,j) - ER.choke2(i); % calculating wall thickness
            j = j + 1; % counting years
        end
        c2(i) = j-1; 
    else
        c2(i) = nan;
    end 
       
    j = 1;
end

plot(x, b2, x, c2)
xlabel('Gas volume in Flow 2 [m3/s]')
xlim([0.1 1])
ylim([0 f])
ylabel('Estimated equipment lifetime [years]')
title('Effect of QG2 on estimated equipment lifetime', 'FontSize', 14)
legend('Elbow 2', 'Choke 2')